@@ -2,6 +2,7 @@ import os
 import urlparse
 
 from django.core.files.base import ContentFile
+from django.utils.encoding import smart_str
 
 from pipeline.conf import settings
 from pipeline.compilers import Compiler
@@ -9,6 +10,7 @@ from pipeline.compressors import Compressor
 from pipeline.glob import glob
 from pipeline.signals import css_compressed, js_compressed
 from pipeline.storage import storage
+from pipeline.utils import filepath_to_uri
 from pipeline.versioning import Versioning
 
 
@@ -39,9 +41,8 @@ class Packager(object):
 
     def individual_url(self, filename):
         relative_path = self.compressor.relative_path(filename)[1:]
-        relative_url = relative_path.replace(os.sep, '/')
         return urlparse.urljoin(settings.PIPELINE_URL,
-            relative_url)
+            filepath_to_uri(relative_path))
 
     def pack_stylesheets(self, package, **kwargs):
         variant = package.get('variant', None)
@@ -85,7 +86,7 @@ class Packager(object):
         return self.compressor.compile_templates(package['templates'])
 
     def save_file(self, path, content):
-        return storage.save(path, ContentFile(content))
+        return storage.save(path, ContentFile(smart_str(content)))
 
     def create_packages(self, config):
         packages = {}
