@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 import base64
+import sys
 
 from mock import patch
 
 from django.test import TestCase
+from django.utils import unittest
 
 from pipeline.conf import settings
 from pipeline.compressors import Compressor
@@ -70,6 +72,9 @@ class CompressorTest(TestCase):
         self.assertEquals(name, 'photo_detail')
         name = self.compressor.template_name('templates/photo_edit.jst', '')
         self.assertEquals(name, 'photo_edit')
+        name = self.compressor.template_name('templates\photo\detail.jst',
+            'templates\\')
+        self.assertEquals(name, 'photo_detail')
 
     def test_compile_templates(self):
         templates = self.compressor.compile_templates(['templates/photo/list.jst'])
@@ -93,6 +98,12 @@ class CompressorTest(TestCase):
         asset_path = self.compressor.construct_asset_path("/images/sprite.png",
             "css/plugins/gallery.css")
         self.assertEquals(asset_path, "http://localhost/static/images/sprite.png")
+    
+    @unittest.skipUnless(sys.platform.startswith("win"), "requires Windows")
+    def test_construct_asset_path_windows(self):
+        asset_path = self.compressor.construct_asset_path("\image\sprite.png",
+            "css\plugins\gallery.css")
+        self.assertEquals(asset_path, "http://localhost/static/images/sprite.png")
 
     def test_construct_asset_path_relative(self):
         asset_path = self.compressor.construct_asset_path("../../images/sprite.png",
